@@ -29,6 +29,89 @@ def async_command(f):
     return wrapper
 
 
+def load_nacos_config(nacos_server=None, nacos_namespace=None, nacos_username=None,
+                     nacos_password=None, nacos_group=None, nacos_data_id=None):
+    import os
+
+    try:
+        nacos_server = nacos_server or os.environ.get('NACOS_SERVER')
+        nacos_namespace = nacos_namespace or os.environ.get('NACOS_NAMESPACE')
+        nacos_username = nacos_username or os.environ.get('NACOS_USERNAME')
+        nacos_password = nacos_password or os.environ.get('NACOS_PASSWORD')
+        nacos_group = nacos_group or os.environ.get('NACOS_GROUP', 'DEFAULT_GROUP')
+        nacos_data_id = nacos_data_id or os.environ.get('NACOS_DATA_ID')
+
+        if not all([nacos_server, nacos_namespace, nacos_group]):
+            missing = []
+            if not nacos_server: missing.append("--nacos-server 或 NACOS_SERVER")
+            if not nacos_namespace: missing.append("--nacos-namespace 或 NACOS_NAMESPACE")
+            if not nacos_group: missing.append("--nacos-group 或 NACOS_GROUP")
+
+            click.echo("Error: Nacos配置不完整，缺少以下配置:", err=True)
+            for item in missing:
+                click.echo(f"  - {item}", err=True)
+            raise click.Abort()
+
+        os.environ['NACOS_SERVER'] = nacos_server
+        os.environ['NACOS_NAMESPACE'] = nacos_namespace
+        os.environ['NACOS_GROUP'] = nacos_group
+        if nacos_data_id:
+            os.environ['NACOS_DATA_ID'] = nacos_data_id
+        if nacos_username:
+            os.environ['NACOS_USERNAME'] = nacos_username
+        if nacos_password:
+            os.environ['NACOS_PASSWORD'] = nacos_password
+
+        click.echo(f"正在从Nacos加载配置 ({nacos_server}/{nacos_namespace})...")
+
+        nacos_config = {}
+
+        nacos_pg_url = config.config.get('JETTASK_PG_URL')
+        if not nacos_pg_url:
+            pg_host = config.config.get('PG_DB_HOST', 'localhost')
+            pg_port = config.config.get('PG_DB_PORT', 5432)
+            pg_user = config.config.get('PG_DB_USERNAME', 'jettask')
+            pg_password = config.config.get('PG_DB_PASSWORD', '123456')
+            pg_database = config.config.get('PG_DB_DATABASE', 'jettask')
+            nacos_pg_url = f'postgresql://{pg_user}:{pg_password}@{pg_host}:{pg_port}/{pg_database}'
+
+        if nacos_pg_url:
+            os.environ['JETTASK_PG_URL'] = nacos_pg_url
+            nacos_config['pg_url'] = nacos_pg_url
+
+        redis_host = config.config.get('REDIS_HOST', 'localhost')
+        redis_port = config.config.get('REDIS_PORT', 6379)
+        redis_db = config.config.get('REDIS_DB', 0)
+        redis_password = config.config.get('REDIS_PASSWORD')
+        if redis_password:
+            redis_url = f'redis://:{redis_password}@{redis_host}:{redis_port}/{redis_db}'
+        else:
+            redis_url = f'redis://{redis_host}:{redis_port}/{redis_db}'
+        os.environ['JETTASK_REDIS_URL'] = redis_url
+        nacos_config['redis_url'] = redis_url
+
+        nacos_api_key = config.config.get('JETTASK_API_KEY') or config.config.get('API_KEY')
+        if nacos_api_key:
+            os.environ['JETTASK_API_KEY'] = nacos_api_key
+            nacos_config['api_key'] = nacos_api_key
+            click.echo(f"✓ 从Nacos获取API密钥配置")
+
+        for key, value in config.config.items():
+            if isinstance(value, (str, int, float, bool)):
+                os.environ[key] = str(value)
+
+        click.echo(f"✓ 从Nacos加载配置成功")
+        return nacos_config
+
+    except click.Abort:
+        raise
+    except Exception as e:
+        click.echo(f"Error: 从Nacos加载配置失败: {e}", err=True)
+        import traceback
+        traceback.print_exc()
+        raise click.Abort()
+
+
 @click.group()
 @click.version_option(version='0.1.0', prog_name='JetTask')
 @click.option('--env-file', '-e', envvar='JETTASK_ENV_FILE',
@@ -87,81 +170,21 @@ def api(ctx, host, port, redis_url, redis_prefix, jettask_pg_url, reload, log_le
     import uvicorn
 
     if use_nacos:
-        try:
-            nacos_server = nacos_server or os.environ.get('NACOS_SERVER')
-            nacos_namespace = nacos_namespace or os.environ.get('NACOS_NAMESPACE')
-            nacos_username = nacos_username or os.environ.get('NACOS_USERNAME')
-            nacos_password = nacos_password or os.environ.get('NACOS_PASSWORD')
-            nacos_group = nacos_group or os.environ.get('NACOS_GROUP', 'DEFAULT_GROUP')
-            nacos_data_id = nacos_data_id or os.environ.get('NACOS_DATA_ID')
+        nacos_config = load_nacos_config(
+            nacos_server=nacos_server,
+            nacos_namespace=nacos_namespace,
+            nacos_username=nacos_username,
+            nacos_password=nacos_password,
+            nacos_group=nacos_group,
+            nacos_data_id=nacos_data_id
+        )
 
-            if not all([nacos_server, nacos_namespace, nacos_group]):
-                missing = []
-                if not nacos_server: missing.append("--nacos-server 或 NACOS_SERVER")
-                if not nacos_namespace: missing.append("--nacos-namespace 或 NACOS_NAMESPACE")
-                if not nacos_group: missing.append("--nacos-group 或 NACOS_GROUP")
-
-                click.echo("Error: Nacos配置不完整，缺少以下配置:", err=True)
-                for item in missing:
-                    click.echo(f"  - {item}", err=True)
-                raise click.Abort()
-
-            os.environ['NACOS_SERVER'] = nacos_server
-            os.environ['NACOS_NAMESPACE'] = nacos_namespace
-            os.environ['NACOS_GROUP'] = nacos_group
-            if nacos_data_id:
-                os.environ['NACOS_DATA_ID'] = nacos_data_id
-            if nacos_username:
-                os.environ['NACOS_USERNAME'] = nacos_username
-            if nacos_password:
-                os.environ['NACOS_PASSWORD'] = nacos_password
-
-            click.echo(f"正在从Nacos加载配置 ({nacos_server}/{nacos_namespace})...")
-
-            nacos_pg_url = config.config.get('JETTASK_PG_URL')
-            if not nacos_pg_url:
-                pg_host = config.config.get('PG_DB_HOST', 'localhost')
-                pg_port = config.config.get('PG_DB_PORT', 5432)
-                pg_user = config.config.get('PG_DB_USERNAME', 'jettask')
-                pg_password = config.config.get('PG_DB_PASSWORD', '123456')
-                pg_database = config.config.get('PG_DB_DATABASE', 'jettask')
-                nacos_pg_url = f'postgresql://{pg_user}:{pg_password}@{pg_host}:{pg_port}/{pg_database}'
-
-            if nacos_pg_url:
-                os.environ['JETTASK_PG_URL'] = nacos_pg_url
-                if not jettask_pg_url:  
-                    jettask_pg_url = nacos_pg_url
-
-            for key, value in config.config.items():
-                if isinstance(value, (str, int, float, bool)):
-                    os.environ[key] = str(value)
-
-            if not redis_url:
-                redis_host = config.config.get('REDIS_HOST', 'localhost')
-                redis_port = config.config.get('REDIS_PORT', 6379)
-                redis_db = config.config.get('REDIS_DB', 0)
-                redis_password = config.config.get('REDIS_PASSWORD')
-                if redis_password:
-                    redis_url = f'redis://:{redis_password}@{redis_host}:{redis_port}/{redis_db}'
-                else:
-                    redis_url = f'redis://{redis_host}:{redis_port}/{redis_db}'
-                os.environ['JETTASK_REDIS_URL'] = redis_url
-
-            if not api_key:
-                nacos_api_key = config.config.get('JETTASK_API_KEY') or config.config.get('API_KEY')
-                if nacos_api_key:
-                    api_key = nacos_api_key
-                    os.environ['JETTASK_API_KEY'] = api_key
-                    click.echo(f"✓ 从Nacos获取API密钥配置")
-
-            click.echo(f"✓ 从Nacos加载配置成功")
-        except click.Abort:
-            raise
-        except Exception as e:
-            click.echo(f"Error: 从Nacos加载配置失败: {e}", err=True)
-            import traceback
-            traceback.print_exc()
-            raise click.Abort()
+        if not jettask_pg_url:
+            jettask_pg_url = nacos_config.get('pg_url')
+        if not redis_url:
+            redis_url = nacos_config.get('redis_url')
+        if not api_key:
+            api_key = nacos_config.get('api_key')
 
     if not jettask_pg_url:
         raise ValueError(
@@ -335,7 +358,7 @@ def worker(app_str, tasks, concurrency, prefetch):
         sys.exit(1)
 
 @cli.command('webui-consumer')
-@click.option('--task-center', '-tc', envvar='JETTASK_CENTER_URL', required=True,
+@click.option('--task-center', '-tc', envvar='JETTASK_CENTER_URL',
               help='任务中心URL，如: http://localhost:8001 或 http://localhost:8001/api/namespaces/default')
 @click.option('--check-interval', type=int, default=30,
               help='命名空间检测间隔（秒），仅多命名空间模式使用，默认30秒')
@@ -343,17 +366,60 @@ def worker(app_str, tasks, concurrency, prefetch):
               help='并发数（每个命名空间的 worker 进程数），默认4')
 @click.option('--prefetch', '-p', type=int, default=1000,
               help='预取倍数（控制每次从队列预取的消息数），默认1000')
+@click.option('--api-key', envvar='JETTASK_API_KEY', help='API密钥用于请求鉴权（与API服务器保持一致）')
+@click.option('--use-nacos', is_flag=True,
+              help='从Nacos配置中心读取配置')
+@click.option('--nacos-server',
+              help='Nacos服务器地址 (如: 127.0.0.1:8848)')
+@click.option('--nacos-namespace',
+              help='Nacos命名空间')
+@click.option('--nacos-username',
+              help='Nacos用户名')
+@click.option('--nacos-password',
+              help='Nacos密码')
+@click.option('--nacos-group',
+              help='Nacos配置组')
+@click.option('--nacos-data-id',
+              help='Nacos配置ID')
 @click.option('--debug', is_flag=True, help='启用调试模式')
-def webui_consumer(task_center, check_interval, concurrency, prefetch, debug):
+def webui_consumer(task_center, check_interval, concurrency, prefetch, api_key,
+                  use_nacos, nacos_server, nacos_namespace, nacos_username, nacos_password,
+                  nacos_group, nacos_data_id, debug):
     import asyncio
+    import os
     from jettask.persistence.manager import UnifiedConsumerManager
 
+    if use_nacos:
+        nacos_config = load_nacos_config(
+            nacos_server=nacos_server,
+            nacos_namespace=nacos_namespace,
+            nacos_username=nacos_username,
+            nacos_password=nacos_password,
+            nacos_group=nacos_group,
+            nacos_data_id=nacos_data_id
+        )
+
+        if not api_key:
+            api_key = nacos_config.get('api_key')
+        if not task_center:
+            task_center = os.environ.get('JETTASK_CENTER_URL', 'http://localhost:8001')
+
+    if not task_center:
+        raise ValueError(
+            "必须提供 --task-center 或在环境变量中设置 JETTASK_CENTER_URL\n"
+            "或使用 jettask webui-consumer --use-nacos 从Nacos加载配置"
+        )
+
+    if api_key:
+        click.echo(f"✓ API密钥已配置（鉴权已启用）")
+
     async def run_manager():
         manager = UnifiedConsumerManager(
             task_center_url=task_center,
             check_interval=check_interval,
             concurrency=concurrency,
             prefetch_multiplier=prefetch,
+            api_key=api_key,
             debug=debug
         )
         await manager.run()
@@ -438,25 +504,68 @@ async def status():
     click.echo("=" * 50)
 
 @cli.command()
-@click.option('--task-center', '-tc', envvar='JETTASK_CENTER_URL', required=True,
+@click.option('--task-center', '-tc', envvar='JETTASK_CENTER_URL',
               help='任务中心URL，如: http://localhost:8001 或 http://localhost:8001/api/namespaces/default')
 @click.option('--interval', '-i', type=float, default=5,
-              help='调度器扫描间隔（秒），默认0.1秒')
+              help='调度器扫描间隔（秒），默认5秒')
 @click.option('--batch-size', '-b', type=int, default=100,
               help='每批处理的最大任务数，默认100')
 @click.option('--check-interval', type=int, default=30,
               help='命名空间检测间隔（秒），仅多命名空间模式使用，默认30秒')
+@click.option('--api-key', envvar='JETTASK_API_KEY', help='API密钥用于请求鉴权（与API服务器保持一致）')
+@click.option('--use-nacos', is_flag=True,
+              help='从Nacos配置中心读取配置')
+@click.option('--nacos-server',
+              help='Nacos服务器地址 (如: 127.0.0.1:8848)')
+@click.option('--nacos-namespace',
+              help='Nacos命名空间')
+@click.option('--nacos-username',
+              help='Nacos用户名')
+@click.option('--nacos-password',
+              help='Nacos密码')
+@click.option('--nacos-group',
+              help='Nacos配置组')
+@click.option('--nacos-data-id',
+              help='Nacos配置ID')
 @click.option('--debug', is_flag=True, help='启用调试模式')
-def scheduler(task_center, interval, batch_size, check_interval, debug):
+def scheduler(task_center, interval, batch_size, check_interval, api_key,
+             use_nacos, nacos_server, nacos_namespace, nacos_username, nacos_password,
+             nacos_group, nacos_data_id, debug):
     import asyncio
+    import os
     from jettask.scheduler.manager import UnifiedSchedulerManager
 
+    if use_nacos:
+        nacos_config = load_nacos_config(
+            nacos_server=nacos_server,
+            nacos_namespace=nacos_namespace,
+            nacos_username=nacos_username,
+            nacos_password=nacos_password,
+            nacos_group=nacos_group,
+            nacos_data_id=nacos_data_id
+        )
+
+        if not api_key:
+            api_key = nacos_config.get('api_key')
+        if not task_center:
+            task_center = os.environ.get('JETTASK_CENTER_URL', 'http://localhost:8001')
+
+    if not task_center:
+        raise ValueError(
+            "必须提供 --task-center 或在环境变量中设置 JETTASK_CENTER_URL\n"
+            "或使用 jettask scheduler --use-nacos 从Nacos加载配置"
+        )
+
+    if api_key:
+        click.echo(f"✓ API密钥已配置（鉴权已启用）")
+
     async def run_manager():
         manager = UnifiedSchedulerManager(
             task_center_url=task_center,
             scan_interval=interval,
             batch_size=batch_size,
             check_interval=check_interval,
+            api_key=api_key,
             debug=debug
         )
         await manager.run()
