@@ -457,14 +457,16 @@ class NamespaceManagerAPI(BaseNamespaceManager):
     - 支持刷新：可以重新从 API 加载最新配置
     """
 
-    def __init__(self, base_url: str):
+    def __init__(self, base_url: str, api_key: Optional[str] = None):
         super().__init__()
-        
+
 
         self.base_url = base_url
-        self._client = TaskCenterClient(base_url)
+        self._client = TaskCenterClient(base_url, api_key=api_key)
 
         logger.info(f"NamespaceManagerAPI 初始化: base_url={base_url}")
+        if api_key:
+            logger.info("API 密钥已配置")
 
     async def refresh(self):
         logger.info(f"从 API 刷新命名空间列表: {self.base_url}")
