@@ -6,7 +6,7 @@
 
 from .task import Task
 from .task_run import TaskRun
-from .scheduled_task import ScheduledTask, TaskExecutionHistory
+from .scheduled_task import ScheduledTask
 from .task_metrics_minute import TaskMetricsMinute
 from .task_runs_metrics_minute import TaskRunsMetricsMinute
 from .sql_history import SQLHistory
@@ -17,7 +17,6 @@ __all__ = [
     'Task',
     'TaskRun',
     'ScheduledTask',
-    'TaskExecutionHistory',
     'TaskMetricsMinute',
     'TaskRunsMetricsMinute',
     'SQLHistory',
