@@ -1,7 +1,7 @@
 """
-ScheduledTask 和 TaskExecutionHistory 模型
+ScheduledTask 模型
 
-对应 scheduled_tasks 和 task_execution_history 表，用于定时任务调度
+对应 scheduled_tasks 表，用于定时任务调度
 """
 from sqlalchemy import (
     Column, BigInteger, String, Integer, Text, Boolean,
@@ -444,85 +444,3 @@ class ScheduledTask(Base):
 
         logger.info(f"批量创建任务: 成功创建 {len(created_tasks)}/{len(tasks)} 个任务")
         return created_tasks
-
-
-class TaskExecutionHistory(Base):
-    """
-    任务执行历史表
-
-    记录定时任务的执行历史
-    """
-    __tablename__ = 'task_execution_history'
-
-    id = Column(BigInteger, primary_key=True, autoincrement=True)
-
-    task_id = Column(
-        BigInteger,
-        nullable=False,
-        comment='关联的任务ID（外键到 scheduled_tasks.id）'
-    )
-    event_id = Column(String(255), nullable=False, comment='执行事件ID')
-
-    scheduled_time = Column(
-        TIMESTAMP(timezone=True),
-        nullable=False,
-        comment='计划执行时间'
-    )
-    started_at = Column(TIMESTAMP(timezone=True), comment='实际开始时间')
-    finished_at = Column(TIMESTAMP(timezone=True), comment='完成时间')
-
-    status = Column(
-        String(50),
-        nullable=False,
-        comment='状态: pending, running, success, failed, timeout'
-    )
-    result = Column(JSONB, comment='执行结果')
-    error_message = Column(Text, comment='错误信息')
-    retry_count = Column(Integer, default=0, comment='重试次数')
-
-    duration_ms = Column(Integer, comment='执行耗时(毫秒)')
-    worker_id = Column(String(100), comment='执行的worker ID')
-
-    created_at = Column(
-        TIMESTAMP(timezone=True),
-        default=lambda: datetime.now(timezone.utc),
-        comment='创建时间'
-    )
-
-    __table_args__ = (
-        Index('idx_task_history_task_id', 'task_id'),
-        Index('idx_task_history_event_id', 'event_id'),
-        Index('idx_task_history_status', 'status'),
-        Index('idx_task_history_scheduled', 'scheduled_time'),
-        Index('idx_task_history_created', 'created_at'),
-    )
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            'id': self.id,
-            'task_id': self.task_id,
-            'event_id': self.event_id,
-            'scheduled_time': self.scheduled_time.isoformat() if self.scheduled_time else None,
-            'started_at': self.started_at.isoformat() if self.started_at else None,
-            'finished_at': self.finished_at.isoformat() if self.finished_at else None,
-            'status': self.status,
-            'result': self.result,
-            'error_message': self.error_message,
-            'retry_count': self.retry_count,
-            'duration_ms': self.duration_ms,
-            'worker_id': self.worker_id,
-            'created_at': self.created_at.isoformat() if self.created_at else None,
-        }
-
-    def __repr__(self) -> str:
-        return f"<TaskExecutionHistory(id={self.id}, task_id={self.task_id}, event_id='{self.event_id}', status='{self.status}')>"
-
-    def calculate_duration(self) -> Optional[int]:
-        if self.started_at and self.finished_at:
-            delta = self.finished_at - self.started_at
-            return int(delta.total_seconds() * 1000)
-        return None
-
-    def update_duration(self):
-        if self.duration_ms is None:
-            self.duration_ms = self.calculate_duration()
