@@ -8,13 +8,12 @@
   - schema.sql: 数据库表结构
 """
 
-from jettask.db.models import ScheduledTask, TaskExecutionHistory, TaskType, TaskStatus
+from jettask.db.models import ScheduledTask, TaskType, TaskStatus
 from .scheduler import TaskScheduler
 from .definition import Schedule
 
 __all__ = [
     'ScheduledTask',
-    'TaskExecutionHistory',
     'TaskType',
     'TaskStatus',
     'TaskScheduler',
