@@ -514,91 +514,6 @@ async def execute_scheduled_task_now(request: Request, task_id: str):
 
 
 
-@router.get(
-    "/{task_id}/history",
-    summary="获取定时任务执行历史",
-    description="获取指定定时任务的执行历史记录，支持分页查询",
-    responses={
-        200: {
-            "description": "成功返回执行历史",
-            "content": {
-                "application/json": {
-                    "example": {
-                        "success": True,
-                        "data": [
-                            {
-                                "id": "exec-001",
-                                "task_id": "task-001",
-                                "job_id": "job-123456",
-                                "status": "completed",
-                                "start_time": "2025-10-19T00:00:00Z",
-                                "end_time": "2025-10-19T00:05:30Z",
-                                "duration": 330,
-                                "result": "success",
-                                "error_message": None
-                            },
-                            {
-                                "id": "exec-002",
-                                "task_id": "task-001",
-                                "job_id": "job-123455",
-                                "status": "failed",
-                                "start_time": "2025-10-18T00:00:00Z",
-                                "end_time": "2025-10-18T00:00:30Z",
-                                "duration": 30,
-                                "result": "error",
-                                "error_message": "Database connection timeout"
-                            }
-                        ],
-                        "total": 150,
-                        "page": 1,
-                        "page_size": 20
-                    }
-                }
-            }
-        },
-        404: {
-            "description": "任务不存在",
-            "content": {
-                "application/json": {
-                    "example": {"detail": "定时任务不存在"}
-                }
-            }
-        },
-        500: {"description": "服务器内部错误"}
-    }
-)
-async def get_scheduled_task_history(
-    request: Request,
-    task_id: str,
-    page: int = Query(1, ge=1, description="页码，从 1 开始", example=1),
-    page_size: int = Query(20, ge=1, le=100, description="每页数量，范围 1-100", example=20)
-):
-    try:
-        app = request.app
-        if not app or not hasattr(app.state, 'data_access'):
-            raise HTTPException(status_code=500, detail="Data access not initialized")
-        
-        data_access = app.state.data_access
-        
-        async with data_access.get_session() as session:
-            history, total = await data_access.fetch_task_execution_history(
-                session=session,
-                task_id=task_id,
-                page=page,
-                page_size=page_size
-            )
-        
-        return {
-            "success": True,
-            "data": history,
-            "total": total,
-            "page": page,
-            "page_size": page_size
-        }
-    except Exception as e:
-        logger.error(f"获取定时任务执行历史失败: {e}")
-        raise HTTPException(status_code=500, detail=str(e))
-
 
 @router.get(
     "/{task_id}/trend",
