@@ -382,82 +382,6 @@ async def _get_top_backlog_queues(namespace, limit, time_range, queues):
 
     _, session_factory = get_pg_engine_and_factory(pg_url)
     async with session_factory() as session:
-        queue_list = []
-        if queues:
-            if isinstance(queues, str):
-                queue_list = [q.strip() for q in queues.split(',') if q.strip()]
-            elif isinstance(queues, list):
-                queue_list = [q.strip() for q in queues if q and q.strip()]
-        
-        try:
-            if queue_list:
-                backlog_sql = text("""
-                    SELECT 
-                        stream_name as queue,
-                        MAX(backlog_unprocessed) as backlog,
-                        CASE 
-                            WHEN MAX(backlog_unprocessed) > 100 THEN 'critical'
-                            WHEN MAX(backlog_unprocessed) > 50 THEN 'warning'
-                            ELSE 'normal'
-                        END as status
-                    FROM stream_backlog_monitor
-                    WHERE namespace = :namespace
-                        AND created_at >= :start_time
-                        AND created_at <= :end_time
-                        AND stream_name = ANY(:queues)
-                    GROUP BY stream_name
-                    HAVING MAX(backlog_unprocessed) > 0
-                    ORDER BY backlog DESC
-                    LIMIT :limit
-                """)
-                
-                result = await session.execute(backlog_sql, {
-                    'namespace': namespace,
-                    'start_time': start_time,
-                    'end_time': end_time,
-                    'queues': queue_list,
-                    'limit': limit
-                })
-            else:
-                backlog_sql = text("""
-                    SELECT 
-                        stream_name as queue,
-                        MAX(backlog_unprocessed) as backlog,
-                        CASE 
-                            WHEN MAX(backlog_unprocessed) > 100 THEN 'critical'
-                            WHEN MAX(backlog_unprocessed) > 50 THEN 'warning'
-                            ELSE 'normal'
-                        END as status
-                    FROM stream_backlog_monitor
-                    WHERE namespace = :namespace
-                        AND created_at >= :start_time
-                        AND created_at <= :end_time
-                    GROUP BY stream_name
-                    HAVING MAX(backlog_unprocessed) > 0
-                    ORDER BY backlog DESC
-                    LIMIT :limit
-                """)
-                
-                result = await session.execute(backlog_sql, {
-                    'namespace': namespace,
-                    'start_time': start_time,
-                    'end_time': end_time,
-                    'limit': limit
-                })
-            
-            backlog_queues = []
-            for row in result.fetchall():
-                backlog_queues.append({
-                    "queue": row.queue,
-                    "backlog": int(row.backlog),
-                    "status": row.status
-                })
-            
-            return {"success": True, "data": backlog_queues}
-            
-        except Exception as e:
-            logger.warning(f"从stream_backlog_monitor获取积压数据失败: {e}")
-            
         return await _get_top_backlog_from_tasks(session, namespace, limit)
 
 
