@@ -447,131 +447,27 @@ class QueueService(BaseService):
         stream_name: Optional[str] = None,
         hours: int = 24
     ) -> Dict[str, Any]:
-        end_time = datetime.now(timezone.utc)
-        start_time = end_time - timedelta(hours=hours)
-        
-        async with data_access.AsyncSessionLocal() as session:
-            if stream_name:
-                query = text("""
-                    SELECT 
-                        stream_name,
-                        consumer_group,
-                        last_published_offset,
-                        last_delivered_offset,
-                        last_acked_offset,
-                        pending_count,
-                        backlog_undelivered,
-                        backlog_unprocessed,
-                        created_at
-                    FROM stream_backlog_monitor
-                    WHERE namespace = :namespace
-                        AND stream_name = :stream_name
-                        AND created_at >= :start_time
-                        AND created_at <= :end_time
-                    ORDER BY created_at DESC
-                    LIMIT 1000
-                """)
-                params = {
-                    'namespace': namespace,
-                    'stream_name': stream_name,
-                    'start_time': start_time,
-                    'end_time': end_time
-                }
-            else:
-                query = text("""
-                    SELECT DISTINCT ON (stream_name, consumer_group)
-                        stream_name,
-                        consumer_group,
-                        last_published_offset,
-                        last_delivered_offset,
-                        last_acked_offset,
-                        pending_count,
-                        backlog_undelivered,
-                        backlog_unprocessed,
-                        created_at
-                    FROM stream_backlog_monitor
-                    WHERE namespace = :namespace
-                        AND created_at >= :start_time
-                    ORDER BY stream_name, consumer_group, created_at DESC
-                """)
-                params = {
-                    'namespace': namespace,
-                    'start_time': start_time
-                }
-            
-            result = await session.execute(query, params)
-            rows = result.fetchall()
-            
-            data = []
-            for row in rows:
-                data.append({
-                    'stream_name': row.stream_name,
-                    'consumer_group': row.consumer_group,
-                    'last_published_offset': row.last_published_offset,
-                    'last_delivered_offset': row.last_delivered_offset,
-                    'last_acked_offset': row.last_acked_offset,
-                    'pending_count': row.pending_count,
-                    'backlog_undelivered': row.backlog_undelivered,
-                    'backlog_unprocessed': row.backlog_unprocessed,
-                    'created_at': row.created_at.isoformat() if row.created_at else None
-                })
-            
-            return {
-                'success': True,
-                'data': data,
-                'total': len(data)
-            }
+        return {
+            'success': False,
+            'data': [],
+            'total': 0,
+            'message': 'stream_backlog_monitor 表已废弃，请使用其他积压监控接口'
+        }
     
     @staticmethod
     async def get_stream_backlog_summary(data_access, namespace: str) -> Dict[str, Any]:
-        async with data_access.AsyncSessionLocal() as session:
-            query = text("""
-                WITH latest_data AS (
-                    SELECT DISTINCT ON (stream_name, consumer_group)
-                        stream_name,
-                        consumer_group,
-                        backlog_undelivered,
-                        backlog_unprocessed,
-                        pending_count
-                    FROM stream_backlog_monitor
-                    WHERE namespace = :namespace
-                        AND created_at >= NOW() - INTERVAL '1 hour'
-                    ORDER BY stream_name, consumer_group, created_at DESC
-                )
-                SELECT 
-                    COUNT(DISTINCT stream_name) as total_streams,
-                    COUNT(DISTINCT consumer_group) as total_groups,
-                    SUM(backlog_unprocessed) as total_backlog,
-                    SUM(pending_count) as total_pending,
-                    MAX(backlog_unprocessed) as max_backlog
-                FROM latest_data
-            """)
-            
-            result = await session.execute(query, {'namespace': namespace})
-            row = result.fetchone()
-            
-            if row:
-                return {
-                    'success': True,
-                    'data': {
-                        'total_streams': row.total_streams or 0,
-                        'total_groups': row.total_groups or 0,
-                        'total_backlog': row.total_backlog or 0,
-                        'total_pending': row.total_pending or 0,
-                        'max_backlog': row.max_backlog or 0
-                    }
-                }
-            else:
-                return {
-                    'success': True,
-                    'data': {
-                        'total_streams': 0,
-                        'total_groups': 0,
-                        'total_backlog': 0,
-                        'total_pending': 0,
-                        'max_backlog': 0
-                    }
-                }
+        return {
+            'success': False,
+            'data': {
+                'total_streams': 0,
+                'total_groups': 0,
+                'total_backlog': 0,
+                'total_pending': 0,
+                'max_backlog': 0
+            },
+            'message': 'stream_backlog_monitor 表已废弃，请使用其他积压监控接口'
+        }
+
 
     @classmethod
     async def get_queue_overview(
